.\" -*- nroff -*- generated from .Rd format
.BG
.FN krige.bayes
.TL
Bayesian analysis for Gaussian geostatistical models
.DN
The function `krige.bayes' performs Bayesian analysis of
geostatistical data for different levels of uncertainty in the model
parameters.
.br
It returns results on the posterior distributions for the model
parameters and on the predictive distributions for prediction
locations (if provided).
.CS

krige.bayes(geodata, coords = geodata$coords, data = geodata$data, locations = "no",
        model = model.control(trend.d = "cte", trend.l = "cte",
                              cov.model = "exponential", kappa = 0.5,
                              aniso.pars = NULL, lambda = 1),
        prior = prior.control(beta.prior = c("flat", "normal", "fixed"),
                              beta = NULL, beta.var = NULL,
                              sill.prior = c("reciprocal", "fixed"), sill = NULL,
                              range.prior = c("uniform", "exponential",
                                    "fixed", "squared.reciprocal", "reciprocal"),
                              exponential.prior.par = 1, range = NULL,
                              range.discrete = NULL,
                              nugget.prior = c("fixed", "uniform"),
                              nugget = 0, nugget.discrete = NULL),
        output = output.control(n.posterior = 1000, n.predictive = NULL,
                                moments = TRUE, simulations.predictive = TRUE,
                                keep.simulations = TRUE, mean.estimator = TRUE,
                                quantile.estimator =  NULL,
                                probability.estimator = NULL,
                                signal = FALSE, messages.screen = TRUE))

.RA
.AG geodata
a list containing elements `$coords' and
`$data' as described next. If not provided the arguments
`coords' and `data' must be provided instead.
.AG coords
a n x 2 matrix where each row have the 2-D
coordinates of the n data locations.
By default it takes the
element `$coords' of the argument `geodata', if provided.
.AG data
a vector with n data values. By default it takes the
element `$data' of the argument `geodata', if provided.
.AG locations
a N x 2 matrix or data-frame with the 2-D
coordinates of the N locations to be predicted.
Defaults to `"no"' in which case
the function returns only results on the posterior distributions of
the model parameters.
.AG model
Defines model components. See section DETAILS below.
.AG prior
Specification of priors for the model parameters. See section DETAILS below.
.AG output
Defines output options. See section DETAILS below.
.RT
A list with components:
.IP "" 
.AG posterior
A list results for the posterior distribution of the
model parameters with the following components:
.AG * beta.summary
summary statistics of the posterior distribution
of the mean parameter beta.
.AG * sigmasq.summary
summary statistics of the posterior distribution
of the variance parameter (sill) sigma^2.
.AG * phi.summary
summary statistics of the posterior distribution
of the correlation parameter (range) phi.
.AG * tausq.summary
summary statistics of the posterior distribution
of the extra variance parameter (nugget) tau^2.
.AG * beta.samples
samples from the posterior distribution of the
mean parameter beta.
.AG * sigmasq.samples
samples from the posterior distribution
of the variance parameter (sill) sigma^2.
.AG * phi.samples
samples from the posterior distribution
of the correlation parameter (range) phi.
.AG * tausq.samples
samples from the posterior distribution
of the extra variance parameter (nugget) tau^2.
.AG * phi.marginal
samples from the marginal posterior distribution
of the correlation parameter (range) phi (averaged over the
distribution of (beta, sigma^2)).
.AG * nugget.marginal
samples from the marginal posterior distribution of the extra variance parameter (nugget) tau^2 (averaged over the
distribution of (beta, sigma^2)).
.AG predictive
A list results for the predictive distribution of the
prediction locations (if provided), with the following
components:
.AG * moments
a matrix where the columns are moments of the
predictive distribution at each prediction location
.AG * simulations
a matrix where each column is a simulations drawn
from the predictive distribution. Returned
only if `keep.simulations = TRUE'.
.AG * mean.simulations
a vector with the mean at the prediction
locations computed using the simulations. Returned
only if `mean.estimator = TRUE'.
.AG * variance.simulations
a vector with the variance at the
prediction locations computed using the simulations. Returned
only if `mean.estimator = TRUE'.
.AG quantile
A matrix or vector with quantile estimators. Returned
only if the argument `quantile.estimator' is used.
.AG * probability
A matrix or vector with probability estimators. Returned
only if the argument `probability.estimator' is used.
.AG * type.prediction
information on the type of prediction performed
.AG message.prediction
information about the type of
inference, concerning parameter uncertainty,
which have been performed.
.AG .Random.seed
system random seed before run the function. Allows reproduction of results. If
the system `\&.Random.seed' is set to this value and the function is run
again, it will produce exactly the same results.
.AG call
the function call

.SH Auxiliary functions
The functions `krige.bayes.aux*' and `*.control' are auxiliary functions called by  `krige.bayes'.

.SH Control functions
`krige.bayes' is a generic function for Bayesian geostatistical 
analysis where predictions take into account the  parameter
uncertainty.
.IP "" 
It can also be set to run conventional kriging methods which
uses known parameters or plug-in estimates. However, the
functions `krige.conv' and `ksline' are more adequate for
prediction with fixed parameters.
.IP "" 
The basis for the Bayesian algorithm is to discretize the prior
distribution for the parameters phi and tau_rel = tau/sigma.
The Tech. Report referenced below provides more information
on the technical details.
.IP "" 
The function call includes auxiliary control functions which allows
the user to specify/change the model components (using `model.control'), prior
distributions (using `prior.control') and 
output options (using `output.control').
There are default options. Only obligatory and arguments to be changed needs
to be specified. The arguments of the controls functions are as follows:
.IP "" 
Control functions arguments:
.IP "" 

.in +

.IP "" 

.in +
Arguments for `model = model.control(...)' :
.IP "" 
.IP "" 
.ti -\w@trend.d\ @u
trend.d\ information about the trend (covariates) values at the data
locations. Possible values are:
.IP "" 
.br
`"cte"' - model with constant mean, i.e. no trend
.IP "" 
.br
`"1st"' - trend is defined as a first degree polynomial on the coordinates
.IP "" 
.br
`"2nd"' - trend is defined as a second degree polynomial on the
coordinates
.IP "" 
.br
 a formula of the type `~X', where `X' is a matrix with covariates (external trend)
at data locations.
.IP "" 
.br
Defaults to `"cte"'.
.IP "" 
.IP "" 
.ti -\w@trend.l\ @u
trend.l\ Specifies the trend (covariate) at prediction
locations. Must be the same type as defined in `trend.d'.
Only used if prediction locations are provided in the argument
`locations'.
.IP "" 
.IP "" 
.ti -\w@cov.model\ @u
cov.model\ model for the correlation function. See options in the
function call and/or documentation for the function `cov.spatial'. 
.IP "" 
.IP "" 
.ti -\w@kappa\ @u
kappa\ additional parameter needed for some of the correlation
functions: (`"matern", "powered.exponential", "gneiting"' and
`"gneiting.matern"'). For more details see documentation for the
function `cov.spatial'. This parameter is always regarded
as fixed during the Bayesian analysis.
.IP "" 
.IP "" 
.ti -\w@aniso.pars\ @u
aniso.pars\ fixed parameters for geometric anisotropy
correction. If `aniso.pars = F' no correction is done otherwise
a vector with 2 values, anisotropy angle and ratio of ranges,
must be provided. Anisotropy correction consists of a
transformation in the data and prediction coordinates performed
by the function `coords.aniso'.
.IP "" 
.IP "" 
.ti -\w@lambda\ @u
lambda\ Box-Cox transformation parameter. If lambda = 1 no
transformation is used, otherwise the Box-Cox data transformation is
performed before the analysis. The transformation parameter lambda
is regarded as a fixed parameter during the Bayesian analysis.
The results are in the same scale as the original data.
If lambda = 0 the log-transformation is performed.
If lambda < 0 the mean predictor doesn't make sense
(the resulting distribution has no expectation). 
.IP "" 

.in -

.IP "" 

.in +
Arguments for `prior = prior.control(...)' :
.IP "" 
.IP "" 
.ti -\w@beta.prior\ @u
beta.prior\ prior distribution for the mean (vector)
parameter beta. The options are "flat" (default), "normal" or "deg"
(degenerated - known mean).
.IP "" 
.IP "" 
.ti -\w@beta\ @u
beta\ hyper-parameter for the distribution of the mean (vector) parameter
beta. Only used if `beta.prior = "normal"' or
`beta.prior = "deg"'. For the later `beta' defines the value of
the known mean.
.IP "" 
.IP "" 
.ti -\w@beta.var\ @u
beta.var\ (co)variance hyper-parameters for the prior of the mean
(vector) parameter beta. Only used if `beta.prior =
          "normal"'.
.IP "" 
.IP "" 
.ti -\w@sill.prior\ @u
sill.prior\ `TRUE' (default) or `FALSE', specifying
whether or not the sill parameter sigma^2 is regarded as random during
analysis. If `TRUE', the prior assigned is
1/sigma^2.
.IP "" 
.IP "" 
.ti -\w@sill\ @u
sill\ fixed value of the sill parameter sigma^2. Only used if
`sill.prior = FALSE'.
.IP "" 
.IP "" 
.ti -\w@range.prior\ @u
range.prior\ prior distribution for the range parameter
phi. Options are: `\"uniform\"', (propto
1),
`\"exponential\"' ,(exp(- nu * phi))
`\"fixed\"', `\"squared.reciprocal\"',
`\"reciprocal\"' (1/phi),
`\"squared.reciprocal\"' (1/phi^2),
`\"fixed\"' (known/estimated value of  phi).
If the latter is defined the parameter phi is
considered as known when performing prediction.
.IP "" 
.IP "" 
.ti -\w@exponential.prior.par\ @u
exponential.prior.par\ parameter nu for the exponential
prior for the parameter phi. Only used if `prior.phi = "exponential"'.
.IP "" 
.IP "" 
.ti -\w@range\ @u
range\ fixed value of the range parameter phi. Only needed if
`range.prior = "fixed"'.
.IP "" 
.IP "" 
.ti -\w@range.discrete\ @u
range.discrete\ support points for the discretisation of the prior
for the range parameter phi.
.IP "" 
.IP "" 
.ti -\w@nugget.prior\ @u
nugget.prior\ specifies a prior distribution for the nugget
parameter tau^2. If `prior.nugget = "fixed"' the nugget is
considered known (fixed) with value given by the argument
`nugget'.
If `prior.nugget = "uniform"' a discrete uniform prior is used
with support points given by the argument `nugget'.
.IP "" 
.IP "" 
.ti -\w@nugget\ @u
nugget\ fixed value for the nugget parameter. Only used if
`prior.nugget = "uniform"'. 
.IP "" 
.IP "" 
.ti -\w@nugget.discrete\ @u
nugget.discrete\ support points for the discretisation of the prior
for the relative nugget parameter
tau^2/sigma^2.
.IP "" 

.in -

.IP "" 

.in +
Arguments for  `output = output.control(...)' :
.IP "" 
.IP "" 
.ti -\w@n.posterior\ @u
n.posterior\ number of samples taken from the posterior
distribution.
.IP "" 
.IP "" 
.ti -\w@n.predictive\ @u
n.predictive\ number of samples taken from the
predictive distribution.
.IP "" 
.IP "" 
.ti -\w@moments\ @u
moments\ if `TRUE' moments of the predictive distribution
are computed without sampling. This works only if `lambda = 1'
or `lambda = 0'.
.IP "" 
.IP "" 
.ti -\w@simulations.predictive\ @u
simulations.predictive\ 
.IP "" 
.IP "" 
.ti -\w@keep.simulations\ @u
keep.simulations\ a flag `TRUE' or `FALSE' indicating
whether or not the samples of the predictive distributions must be
kept.
Only used if prediction locations are provided on the argument `locations'.
.IP "" 
.IP "" 
.ti -\w@mean.estimator\ @u
mean.estimator\ a flag `TRUE' or `FALSE' indicating
whether or not the mean and variances of the predictive distributions must be
computed and kept. If `TRUE' objects `predict.mean' and
`krige.var' are included in the output.
Only used prediction locations are provided on the argument `locations'.
.IP "" 
.IP "" 
.ti -\w@quantile.estimator\ @u
quantile.estimator\ indicates
whether or not quantiles of the predictive distributions must be
computed and kept. If a vector with numbers in the interval
[0,1] is provided the corresponding quantile(s) estimators
are included in the output in the object `quantiles'. For
example, if `estimator = c(0.25,0.50,0.75)' the function
returns the 1st quartile, median and 3rd quartile for each location.
If `TRUE', the default is the vector c(0.025, 0.5, 0.975)
and an uncertainty measure which is an analogy to the kriging
standard error can be computed by (q0.975 - q0.025)/4.
Only used prediction locations are provided on the argument `locations'.
.IP "" 
.IP "" 
.ti -\w@probability.estimator\ @u
probability.estimator\ the default is `FALSE'. If some
cutoff values are provided instead, an object called
`probability' is included in the output providing, for each
location, the probability of the variable be less or equal than the
cutoff value given by the argument.
.IP "" 
.IP "" 
.ti -\w@signal\ @u
signal\ if `TRUE' the signal is predict, otherwise the
variable is predict. If no transformation is performed the
expectations are the same in both cases and the difference is only in
the kriging variance, if nugget is different form zero.
.IP "" 
.IP "" 
.ti -\w@messages.screen\ @u
messages.screen\ a flag `TRUE' or `FALSE' indicating
whether or not messages are printed on the screen (or output file)
while the function is running.
.IP "" 

.in -
   

.in -

.SH REFERENCES
The technical details for `krige.bayes' implementation can be
found at:
.IP "" 
.br
.IP "" 
Ribeiro, P.J. Jr. and Diggle, P.J. (1999) Bayesian inference in
Gaussian model-based geostatistics. Tech. Report ST-99-08, Depto
Maths and Stats, Lancaster University.
Available at: 
<URL: http://www.maths.lancs.ac.uk/~ribeiro/publications.html>
.IP "" 
Further information about `geoR/geoS' can be found at:
.IP "" 
.br
<URL: http://www.maths.lancs.ac.uk/~ribeiro/geoR.html>
.SA
`lines.krige.bayes',
`image.krige.bayes',
`persp.krige.bayes',  
`krige.conv',
`ksline'.
.EX
# generating a simulated data-set
ex.data <- grf(50, cov.pars=c(10, .25))
#
# defining the prediction grid:
ex.grid <- as.matrix(expand.grid(seq(0,1,l=11), seq(0,1,l=11)))
#
# computing Bayesian posterior and predictive distributions  


ex.bayes <- krige.bayes(ex.data, loc=ex.grid, prior =
                 prior.control(range.discrete=seq(0, 2, l=51)))

#
# Ploting theoretical amd empirical variograms
plot(ex.data)
# adding lines with fitted variograms
lines(ex.bayes, max.dist=1.2)
lines(ex.bayes, max.dist=1.2, summ="median", lty=2)
lines(ex.bayes, max.dist=1.2, summ="mean", lwd=2, lty=2)
#
# Ploting prediction some results
par.mf <- par()$mfrow
par(mfrow=c(2,2))
image.krige.bayes(ex.bayes, loc=ex.grid, main="predicted values")
image.krige.bayes(ex.bayes, val="moments.variance",
                  loc=ex.grid, main="prediction variance")
image.krige.bayes(ex.bayes, val= "simulation", number.col=1,
                  loc=ex.grid, main="a simulation from\\nthe predictive distribution")
image.krige.bayes(ex.bayes, val= "simulation", number.col=2,
                  loc=ex.grid, main="another simulation from \\n the predictive distribution")
par(mfrow=par.mf)

.KW spatial
.WR
