.\" -*- nroff -*- generated from .Rd format
.BG
.FN krige.conv
.TL
Spatial interpolation (kriging) with fixed covariance parameters
.DN
This function performs spatial prediction for fixed covariance
parameters, using a global neighborhood.
.IP "" 
It can produce results which corresponds to the following kriging
types: SK (simple kriging), OK (ordinary kriging), KTE (external trend kriging), UK (universal kriging).
.CS

krige.conv(geodata, coords = geodata$coords, data = geodata$data, 
           locations,
           krige = krige.control(type.krige, beta = NULL,
                     trend.d, trend.l, cov.model, cov.pars,
                     kappa = 0.5, nugget = 0, micro.scale = 0,
                     dist.epsilon = 1e-10, aniso.pars = NULL, 
                     lambda = 1, signal = FALSE,
                     n.samples.backtransform = 500, n.sim = 0),
           messages.screen = TRUE) 

.RA
.AG geodata
a list containing elements `$coords' and
`$data' as described next. If not provided the arguments
`coords' and `data' must be provided instead.
.AG coords
a n x 2 matrix where each row have the 2-D
coordinates of the n data locations.
By default it takes the
element `$coords' of the argument `geodata', if provided.
.AG data
a vector with n data values. By default it takes the
element `$data' of the argument `geodata', if provided.
.AG locations
a N x 2 matrix or data-frame with the 2-D
coordinates of the N locations to be predicted.
.AG krige
defines the model components and several options for
kriging. ATTENTION: the argument `cov.pars' is obligatory and
the others have default options.
See section DETAILS below.
.AG messages.screen
a flag `TRUE' or `FALSE' indicating
whether or not messages are printed on the screen (or output file)
while the function is running.
.RT
A list with components:
.IP "" 
.AG predict
a vector with predicted value at the prediction locations.
.AG krige.var
a vector with predicted variances at the prediction locations.
.AG beta.est
estimates of the beta parameter
implicitly done during the kriging procedure. Not used if
`type.krige = \"SK\"'.
.AG simulations
a matrix ni x n.sim where ni is the
number of prediction locations. Each column corresponds to a simulations of the predictive distribution
(conditional simulation). Only returned if `n.sim > 0'.
.AG message
messages about the type of prediction performed.
.AG call
stores the function call.
.SH REFERENCES
Further information about `geoR/geoS' can be found at:
.br
<URL: http://www.maths.lancs.ac.uk/~ribeiro/geoR.html>
.SA
`image.kriging', `krige.bayes', `ksline'.
.EX

data(s100)   # only when using R (not necessary with S-PLUS) 
loci <- expand.grid(seq(0,1,l=31), seq(0,1,l=31))
kc <- krige.conv(s100, loc=loci, krige=krige.control(cov.pars=c(1, .25)))
par(mfrow=c(1,2))
image.kriging(kc, loc=loci, main="kriging estimates")
image.kriging(kc, loc=loci, val=sqrt(kc$krige.var), main="kriging std. errors")

.KW spatial
.WR
